@@ -9,10 +9,21 @@ from qecore.logger import QELogger
 
 log = QELogger()
 
+
 class Application:
-    def __init__(self, component, a11y_app_name=None, desktop_file_exists=True,
-                 desktop_file_name="", desktop_file_path="", app_process_name="",
-                 shell=None, session_type="", session_desktop="", kiosk=None):
+    def __init__(
+        self,
+        component,
+        a11y_app_name=None,
+        desktop_file_exists=True,
+        desktop_file_name="",
+        desktop_file_path="",
+        app_process_name="",
+        shell=None,
+        session_type="",
+        session_desktop="",
+        kiosk=None,
+    ):
         """
         .. note::
 
@@ -38,14 +49,18 @@ class Application:
         :param app_process_name: Name of application process if not same as component.
         """
 
-        log.info(" ".join((
-                f"__init__(self, component={component}, a11y_app_name={a11y_app_name},",
-                f"desktop_file_exists={desktop_file_exists},",
-                f"desktop_file_name={desktop_file_name},",
-                f"desktop_file_path={desktop_file_path},",
-                f"app_process_name={app_process_name}, shell='shell',",
-                f"session_type={session_type}, session_desktop={session_desktop})"
-        )))
+        log.info(
+            " ".join(
+                (
+                    f"__init__(self, component={component}, a11y_app_name={a11y_app_name},",
+                    f"desktop_file_exists={desktop_file_exists},",
+                    f"desktop_file_name={desktop_file_name},",
+                    f"desktop_file_path={desktop_file_path},",
+                    f"app_process_name={app_process_name}, shell='shell',",
+                    f"session_type={session_type}, session_desktop={session_desktop})",
+                )
+            )
+        )
 
         self.shell = shell
         self.kiosk = kiosk
@@ -66,7 +81,7 @@ class Application:
         self.icon = None
         self.get_desktop_file_data()
 
-        if 'Flatpak' not in f'{type(self)}':
+        if "Flatpak" not in f"{type(self)}":
             # Preserving old api names of functions.
             self.getDesktopFileData = self.get_desktop_file_data
             self.getRoot = self.get_root
@@ -74,7 +89,6 @@ class Application:
             self.getPidList = self.get_pid_list
             self.getAllKillCandidates = self.get_all_kill_candidates
 
-
     def get_desktop_file_data(self):
         """
         Parse desktop file.
@@ -89,45 +103,59 @@ class Application:
         # zenity/gnome-shell do not have desktop file.
         if self.desktop_file_exists:
             if self.desktop_file_path:
-                log.info(f"get_desktop_file_data: loading user provided .desktop file: '{self.desktop_file_path}'")
+                log.info(
+                    f"get_desktop_file_data: loading user provided .desktop file: '{self.desktop_file_path}'"
+                )
                 desktop_file = self.desktop_file_path
             else:
-                desktop_run = run(" ".join((
-                    f"rpm -qlf $(which {self.component}) |",
-                    "grep /usr/share/applications/ |",
-                    "grep .desktop |",
-                    f"grep '{self.desktop_file_name}'"
-                )), verbose=True)
+                desktop_run = run(
+                    " ".join(
+                        (
+                            f"rpm -qlf $(which {self.component}) |",
+                            "grep /usr/share/applications/ |",
+                            "grep .desktop |",
+                            f"grep '{self.desktop_file_name}'",
+                        )
+                    ),
+                    verbose=True,
+                )
 
                 if desktop_run[1] != 0:
-                    raise Exception(f"Desktop file of application '{self.component}' was not found.")
+                    raise Exception(
+                        f"Desktop file of application '{self.component}' was not found."
+                    )
 
                 desktop_file = desktop_run[0].strip("\n")
-                log.info(f"get_desktop_file_data: .desktop file found: '{desktop_file}'")
+                log.info(
+                    f"get_desktop_file_data: .desktop file found: '{desktop_file}'"
+                )
 
             desktop_files_list = desktop_file.split("\n")
             if len(desktop_files_list) != 1:
-                assert False, "\n".join((
-                    f"More than one .desktop file found: \n{desktop_file}\n",
-                    "Specify one when initializing your application in environment.py, options are:",
-                    "1) Specify your <name>.desktop file name 'desktop_file_name=\"<name>\"'.",
-                    "2) Provide full path to your .desktop file 'desktop_file_path=\"/path/to/desktop/file\"'.",
-                    " ... = context.sandbox.get_application(..., desktop_file_name=\"\", desktop_file_path=\"\")\n"
-                ))
+                assert False, "\n".join(
+                    (
+                        f"More than one .desktop file found: \n{desktop_file}\n",
+                        "Specify one when initializing your application in environment.py, options are:",
+                        "1) Specify your <name>.desktop file name 'desktop_file_name=\"<name>\"'.",
+                        "2) Provide full path to your .desktop file 'desktop_file_path=\"/path/to/desktop/file\"'.",
+                        ' ... = context.sandbox.get_application(..., desktop_file_name="", desktop_file_path="")\n',
+                    )
+                )
 
             desktop_file_config = configparser.RawConfigParser()
             list_of_successfully_parsed_files = desktop_file_config.read(desktop_file)
 
             if list_of_successfully_parsed_files == []:
-                assert False, "".join((
-                    f"Failed attepmt to parse the .desktop file: '{desktop_file}'."
-                ))
+                assert False, "".join(
+                    (f"Failed attepmt to parse the .desktop file: '{desktop_file}'.")
+                )
 
             self.name = desktop_file_config.get("Desktop Entry", "name")
             self.exec = desktop_file_config.get("Desktop Entry", "exec").split(" ")[0]
             self.icon = desktop_file_config.get("Desktop Entry", "icon", fallback=None)
-            log.info(f"get_desktop_file_data: data name='{self.name}' exec='{self.exec}' icon='{self.icon}'")
-
+            log.info(
+                f"get_desktop_file_data: data name='{self.name}' exec='{self.exec}' icon='{self.icon}'"
+            )
 
     def start_via_command(self, command=None, **kwargs):
         """
@@ -150,10 +178,14 @@ class Application:
             if "kill" in str(key).lower():
                 kill_override = val
 
-        log.info("".join((
-                f"{self.component} ",
-                f"start_via_command(self, command={command}, in_session={in_session})"
-        )))
+        log.info(
+            "".join(
+                (
+                    f"{self.component} ",
+                    f"start_via_command(self, command={command}, in_session={in_session})",
+                )
+            )
+        )
 
         if self.is_running() and kill_override:
             self.kill_application()
@@ -169,15 +201,16 @@ class Application:
             sleep(0.5)
             keyCombo("<Alt><F2>")
             sleep(0.5)
-            enter_a_command = self.shell.findChild(lambda x: "activate" in x.actions and x.showing)
+            enter_a_command = self.shell.findChild(
+                lambda x: "activate" in x.actions and x.showing
+            )
             enter_a_command.text = command_to_use
             sleep(0.5)
             pressKey("Enter")
         else:
-            self.process = Popen(shlex.split(command_to_use),
-                                 stdout=PIPE,
-                                 stderr=PIPE,
-                                 encoding="utf-8")
+            self.process = Popen(
+                shlex.split(command_to_use), stdout=PIPE, stderr=PIPE, encoding="utf-8"
+            )
 
             process_is_running = self.process.poll() is None
             if not process_is_running:
@@ -186,17 +219,18 @@ class Application:
                 stdout_data = stdout_data.strip("\n")
                 stderr_data = stderr_data.strip("\n")
 
-                error_message = "\n".join((
-                    f"The command used to start the application '{command_to_use}' failed.",
-                    f"The 'stdout_data' of executed command are: '{stdout_data}'.",
-                    f"The 'stderr_data' of executed command are: '{stderr_data}'."
-                ))
+                error_message = "\n".join(
+                    (
+                        f"The command used to start the application '{command_to_use}' failed.",
+                        f"The 'stdout_data' of executed command are: '{stdout_data}'.",
+                        f"The 'stderr_data' of executed command are: '{stderr_data}'.",
+                    )
+                )
                 raise RuntimeError(error_message)
 
         self.wait_before_app_starts(30)
         self.instance = self.get_root()
 
-
     def start_via_menu(self, kill=None):
         """
         Start application via menu.
@@ -212,15 +246,19 @@ class Application:
             raise RuntimeError("Start via menu is not available in kiosk mode.")
 
         if "classic" in self.session_desktop:
-            assert False, "".join((
-                f"Application cannot be started via menu in {self.session_desktop}."
-            ))
+            assert False, "".join(
+                (f"Application cannot be started via menu in {self.session_desktop}.")
+            )
 
         if not self.desktop_file_exists:
-            raise Exception("".join((
-                f"Testing target '{self.a11y_app_name}' does not have desktop file. ",
-                "Indication of user failure!"
-            )))
+            raise Exception(
+                "".join(
+                    (
+                        f"Testing target '{self.a11y_app_name}' does not have desktop file. ",
+                        "Indication of user failure!",
+                    )
+                )
+            )
 
         kill_override = kill if kill else self.kill
 
@@ -236,7 +274,6 @@ class Application:
         self.wait_before_app_starts(30)
         self.instance = self.get_root()
 
-
     def close_via_shortcut(self):
         """
         Close application via shortcut.
@@ -254,17 +291,20 @@ class Application:
         log.info(f"{self.component} close_via_shortcut(self)")
 
         if not self.is_running():
-            raise Exception("".join((
-                f"Application '{self.a11y_app_name}' is no longer running. ",
-                "Indication of test failure!"
-            )))
+            raise Exception(
+                "".join(
+                    (
+                        f"Application '{self.a11y_app_name}' is no longer running. ",
+                        "Indication of test failure!",
+                    )
+                )
+            )
 
         keyCombo(self.exit_shortcut)
 
         self.wait_before_app_closes(30)
         self.instance = None
 
-
     def already_running(self):
         """
         If application is started by other means, other than methods from this class,
@@ -276,7 +316,6 @@ class Application:
         self.wait_before_app_starts(15)
         self.instance = self.get_root()
 
-
     def get_root(self):
         """
         Get accessibility root of appllication.
@@ -293,8 +332,8 @@ class Application:
         # Importing here for issue with accessibility if the connection is not ready yet.
         # This will make sure the import will happen after the session is loaded.
         from dogtail.tree import root
-        return root.application(self.a11y_app_name)
 
+        return root.application(self.a11y_app_name)
 
     def is_running(self):
         """
@@ -325,7 +364,6 @@ class Application:
         except Exception:
             return False
 
-
     def get_pid_list(self):
         """
         Get list of processes of running application.
@@ -347,7 +385,6 @@ class Application:
 
         return None
 
-
     def get_all_kill_candidates(self):
         """
         Take result of :func:`get_pid_list` and return only processes of application.
@@ -376,10 +413,12 @@ class Application:
 
         final_pid_list = []
         for process in application_pid_list:
-            if not (("runtest" in process) or \
-                    ("behave" in process) or \
-                    ("dogtail" in process) or \
-                    (process == "/usr/bin/gnome-shell")):
+            if not (
+                ("runtest" in process)
+                or ("behave" in process)
+                or ("dogtail" in process)
+                or (process == "/usr/bin/gnome-shell")
+            ):
                 extracted_pid = process.split(" ", 1)[0]
                 try:
                     final_pid_list.append(int(extracted_pid))
@@ -389,7 +428,6 @@ class Application:
 
         return final_pid_list
 
-
     def kill_application(self):
         """
         Kill application.
@@ -409,7 +447,6 @@ class Application:
             else:
                 run(self.kill_command)
 
-
     # Following two could be merged, I could not think of a nice way of doing it though.
     def wait_before_app_starts(self, time_limit):
         """
@@ -419,10 +456,14 @@ class Application:
         :param time_limit: Number which signifies time before the run is stopped.
         """
 
-        log.info("".join((
-                f"{self.component} ",
-                f"wait_before_app_starts(self, time_limit={time_limit})"
-        )))
+        log.info(
+            "".join(
+                (
+                    f"{self.component} ",
+                    f"wait_before_app_starts(self, time_limit={time_limit})",
+                )
+            )
+        )
 
         for _ in range(time_limit * 10):
             if not self.is_running():
@@ -430,9 +471,11 @@ class Application:
             else:
                 return
 
-        assert False, "".join((
-            f"Application '{self.a11y_app_name}' was not found in application tree: '{self.application_list}'."
-        ))
+        assert False, "".join(
+            (
+                f"Application '{self.a11y_app_name}' was not found in application tree: '{self.application_list}'."
+            )
+        )
 
     def wait_before_app_closes(self, time_limit):
         """
@@ -442,10 +485,14 @@ class Application:
         :param time_limit: Number which signifies time before the run is stopped.
         """
 
-        log.info("".join((
-                f"{self.component} ",
-                f"wait_before_app_closes(self, time_limit={time_limit}"
-        )))
+        log.info(
+            "".join(
+                (
+                    f"{self.component} ",
+                    f"wait_before_app_closes(self, time_limit={time_limit}",
+                )
+            )
+        )
 
         for _ in range(time_limit * 10):
             if self.is_running():
@@ -453,47 +500,8 @@ class Application:
             else:
                 return
 
-        assert False, "".join((
-            f"Application '{self.a11y_app_name}' was still found in application tree: '{self.application_list}'."
-        ))
-
-
-    # Using properties to preserve old api of attributes.
-    @property
-    def a11yAppName(self):
-        return self.a11y_app_name
-    @a11yAppName.setter
-    def a11yAppName(self, value):
-        self.a11y_app_name = value
-
-
-    @property
-    def desktopFileExists(self):
-        return self.desktop_file_exists
-    @desktopFileExists.setter
-    def desktopFileExists(self, value):
-        self.desktop_file_exists = value
-
-
-    @property
-    def exitShortcut(self):
-        return self.exit_shortcut
-    @exitShortcut.setter
-    def exitShortcut(self, value):
-        self.exit_shortcut = value
-
-
-    @property
-    def desktopFileName(self):
-        return self.desktop_file_name
-    @desktopFileName.setter
-    def desktopFileName(self, value):
-        self.desktop_file_name = value
-
-
-    @property
-    def appProcessName(self):
-        return self.app_process_name
-    @appProcessName.setter
-    def appProcessName(self, value):
-        self.app_process_name = value
+        assert False, "".join(
+            (
+                f"Application '{self.a11y_app_name}' was still found in application tree: '{self.application_list}'."
+            )
+        )
