@@ -7,6 +7,7 @@ from qecore.application import Application
 
 __author__ = """Martin Krajnak <mkrajnak@redhat.com>"""
 
+
 class Flatpak(Application):
     def __init__(self, flatpak_id, **kwargs):
         """
@@ -21,11 +22,11 @@ class Flatpak(Application):
 
         if flatpak_id.count(".") != 2:
             raise Exception(
-                f"Incorrect flatpak name {flatpak_id}, e.g.: org.gnome.gedit")
+                f"Incorrect flatpak name {flatpak_id}, e.g.: org.gnome.gedit"
+            )
 
         super().__init__(component=flatpak_id, **kwargs)
 
-
     def kill_application(self):
         """
         Killing via 'flatpak kill <flatpak_id>', sudo for @system flatpaks
@@ -37,7 +38,6 @@ class Flatpak(Application):
             # Kills a flatpak installed @User.
             run(f"flatpak kill {self.component}")
 
-
     def get_desktop_file_data(self):
         """
         Provide information from .desktop file, two possible locations:
@@ -62,7 +62,7 @@ class Flatpak(Application):
             desktop_file_name = self.desktop_file_name or self.component
             for root, _, files in walk(flatpak_dir):
                 for f in files:
-                    if '.desktop' in f and desktop_file_name in f:
+                    if ".desktop" in f and desktop_file_name in f:
                         return path.join(root, f)
             return None
 
@@ -73,10 +73,10 @@ class Flatpak(Application):
         if self.desktop_file_path:
             desktop_file = self.desktop_file_path
         else:
-            for pth in ['~/.local/share/flatpak/app/', '/var/lib/flatpak/app/']:
+            for pth in ["~/.local/share/flatpak/app/", "/var/lib/flatpak/app/"]:
                 pth = path.expanduser(pth)
-                if path.isdir(f'{pth}{self.component}'):
-                    desktop_file = get_desktop_file_path(f'{pth}{self.component}')
+                if path.isdir(f"{pth}{self.component}"):
+                    desktop_file = get_desktop_file_path(f"{pth}{self.component}")
                     break
 
         if not desktop_file:
@@ -89,13 +89,11 @@ class Flatpak(Application):
         self.exec = f"flatpak run {self.component}"
         self.icon = desktop_file_config.get("Desktop Entry", "icon", fallback=None)
 
-
     def is_running(self):
         """
         Double check if running application is really a flatpak
         """
-        return super().is_running() and (self.component in run('flatpak ps'))
-
+        return super().is_running() and (self.component in run("flatpak ps"))
 
     def start_via_menu(self, kill=False):
         """
@@ -110,13 +108,12 @@ class Flatpak(Application):
         rpms = run(f'rpm -qa | grep -i "{self.name}"')
         if rpms:
             print(
-                f'WARNING: a method could possibly start a non-flatpak application\n'
-                f'{self.name} is already instaled as .rpm: {rpms}'
+                f"WARNING: a method could possibly start a non-flatpak application\n"
+                f"{self.name} is already instaled as .rpm: {rpms}"
             )
 
         super().start_via_menu(kill)
 
-
     @property
     def get_pid_list(self):
         """
@@ -129,7 +126,6 @@ class Flatpak(Application):
 
         raise NotImplementedError("Not available for flatpak objects")
 
-
     @property
     def get_all_kill_candidates(self):
         """
