@@ -98,7 +98,9 @@ class GetNode:
         self.size_low = string_to_int_tuple(kwargs.get("size_low", "1,0"))
         self.size_high = string_to_int_tuple(kwargs.get("size_high", "1000000,1000000"))
         self.position_low = string_to_int_tuple(kwargs.get("position_low", "0,0"))
-        self.position_high = string_to_int_tuple(kwargs.get("position_high", "1000000,1000000"))
+        self.position_high = string_to_int_tuple(
+            kwargs.get("position_high", "1000000,1000000")
+        )
 
         a11y_root_name = kwargs.get("a11y_root_name", None)
         retry = kwargs.get("retry", False)
@@ -114,7 +116,9 @@ class GetNode:
                 try:
                     self.root = root.application(a11y_root_name)
                 except Exception as error:
-                    raise Exception(f"You are attempting to use '{a11y_root_name}' as root application.\n{error}")
+                    raise Exception(
+                        f"You are attempting to use '{a11y_root_name}' as root application.\n{error}"
+                    )
 
         # Root accessibility object's name is not given.
         else:
@@ -123,26 +127,25 @@ class GetNode:
                 self.root = context.sandbox.default_application.instance
             except AttributeError:
                 traceback.print_exc(file=sys.stdout)
-                assert False, "".join((
-                    "\nYou need to define a default application ",
-                    "if you are using steps without root."
-                ))
+                assert False, "".join(
+                    (
+                        "\nYou need to define a default application ",
+                        "if you are using steps without root.",
+                    )
+                )
 
         # Condition to do any action on any node, is that the application is running.
         application_list = [x.name for x in root.applications()]
-        if not self.root.name in application_list:
-            assert False, "".join((
-                f"You are trying to do action in application: '{self.root.name}' ",
-                "which is not detected running.\n",
-                f"Detected applications are: '{application_list}'"
-            ))
+        if self.root.name not in application_list:
+            assert False, "".join(
+                (
+                    f"You are trying to do action in application: '{self.root.name}' ",
+                    "which is not detected running.\n",
+                    f"Detected applications are: '{application_list}'",
+                )
+            )
 
-        mouse_map = {
-            "Left": 1,
-            "Middle": 2,
-            "Right": 3,
-            "None": None
-        }
+        mouse_map = {"Left": 1, "Middle": 2, "Right": 3, "None": None}
         try:
             self.m_btn = mouse_map[str(m_btn)]
         except KeyError:
@@ -162,42 +165,74 @@ class GetNode:
         self.role_name = string_to_regex(role_name)
         self.description = string_to_regex(description, flags=re.DOTALL | re.MULTILINE)
 
-        defined_attributes = ["showing", "visible", "checked", "focused", "focusable", "sensitive"]
-        self.attr = attr if attr in defined_attributes else None if attr is None else False
-        assert self.attr is not False, "\n".join((
-            "\nUnknown attribute. Check your feature file!",
-            f"Attributes defined are '{str(defined_attributes)}'. You tried to use: '{self.attr}'"
-        ))
+        defined_attributes = [
+            "showing",
+            "visible",
+            "checked",
+            "focused",
+            "focusable",
+            "sensitive",
+        ]
+        self.attr = (
+            attr if attr in defined_attributes else None if attr is None else False
+        )
+        assert self.attr is not False, "\n".join(
+            (
+                "\nUnknown attribute. Check your feature file!",
+                f"Attributes defined are '{str(defined_attributes)}'. You tried to use: '{self.attr}'",
+            )
+        )
 
         self.retry = retry if isinstance(retry, bool) else None
-        assert self.retry is not None, "\n".join((
-            "\nUnknown retry state. Check your feature file!",
-            f"Expected attribute is 'True' or 'False'. You tried to use: '{self.attr}'"
-        ))
-
-        self.expect_positive = expect_positive if isinstance(expect_positive, bool) else None
-        assert self.expect_positive is not None, "".join((
-            f"\nUnknown expect_positive state. Check your feature file!"
-            f"Expected attribute is 'True' or 'False'. You tried to use: '{self.expect_positive}'"
-        ))
+        assert self.retry is not None, "\n".join(
+            (
+                "\nUnknown retry state. Check your feature file!",
+                f"Expected attribute is 'True' or 'False'. You tried to use: '{self.attr}'",
+            )
+        )
 
+        self.expect_positive = (
+            expect_positive if isinstance(expect_positive, bool) else None
+        )
+        assert self.expect_positive is not None, "".join(
+            (
+                f"\nUnknown expect_positive state. Check your feature file!"
+                f"Expected attribute is 'True' or 'False'. You tried to use: '{self.expect_positive}'"
+            )
+        )
 
     def __enter__(self):
         try:
             found_node = self.root.findChild(
-                lambda x:
-                    ((not isinstance(self.name, str)) or self.name in repr(x.name))
-                    and ((not isinstance(self.name, re.Pattern)) or re.fullmatch(self.name, x.name))
-                    and ((not isinstance(self.role_name, str)) or self.role_name == x.roleName)
-                    and ((not isinstance(self.role_name, re.Pattern)) or re.fullmatch(self.role_name, x.roleName))
-                    and ((not isinstance(self.description, str)) or self.description == x.description)
-                    and ((not isinstance(self.description, re.Pattern)) or re.fullmatch(self.description, x.description))
-                    and ((self.attr is None) or getattr(x, self.attr))
-                    and Tuple(x.position) >= self.position_low
-                    and Tuple(x.position) <= self.position_high
-                    and Tuple(x.size) >= self.size_low
-                    and Tuple(x.size) <= self.size_high,
-                retry=self.retry
+                lambda x: (
+                    (not isinstance(self.name, str)) or self.name in repr(x.name)
+                )
+                and (
+                    (not isinstance(self.name, re.Pattern))
+                    or re.fullmatch(self.name, x.name)
+                )
+                and (
+                    (not isinstance(self.role_name, str))
+                    or self.role_name == x.roleName
+                )
+                and (
+                    (not isinstance(self.role_name, re.Pattern))
+                    or re.fullmatch(self.role_name, x.roleName)
+                )
+                and (
+                    (not isinstance(self.description, str))
+                    or self.description == x.description
+                )
+                and (
+                    (not isinstance(self.description, re.Pattern))
+                    or re.fullmatch(self.description, x.description)
+                )
+                and ((self.attr is None) or getattr(x, self.attr))
+                and Tuple(x.position) >= self.position_low
+                and Tuple(x.position) <= self.position_high
+                and Tuple(x.size) >= self.size_low
+                and Tuple(x.size) <= self.size_high,
+                retry=self.retry,
             )
         except Exception as error:
             if self.expect_positive:
@@ -206,7 +241,6 @@ class GetNode:
                 found_node = None
         return (self, found_node)
 
-
     def __exit__(self, exc_type, exc_value, trcb):
         if exc_type is not None:
             return False
@@ -223,7 +257,7 @@ def get_center(node):
     :rtype: tuple
     :return: Tuple with coordinates of the center of a Node.
     """
-    return (node.position[0] + node.size[0]/2, node.position[1] + node.size[1]/2)
+    return (node.position[0] + node.size[0] / 2, node.position[1] + node.size[1] / 2)
 
 
 def get_formated_duplicates(list_size, list_of_duplicates, attr):
@@ -248,19 +282,45 @@ def get_formated_duplicates(list_size, list_of_duplicates, attr):
         Used by :py:func:`get_error_message`.
     """
 
-    return "".join(sorted(set(["\t{0}: '{1}' {2}: '{3}' {4}: '{5}' {6}: '{7}' {8}: '{9}'\n".format(
-        colored("name", "yellow") if QE_DEVELOPMENT else "name", repr(node.name),
-        colored("roleName", "yellow") if QE_DEVELOPMENT else "roleName", node.roleName,
-        colored("position", "yellow") if QE_DEVELOPMENT else "position", node.position,
-        colored("size", "yellow") if QE_DEVELOPMENT else "size", node.size,
-        colored(f"{attr}", "yellow") if QE_DEVELOPMENT else f"{attr}" \
-            if attr else "attribute", getattr(node, attr) if attr else "None") \
-    for node in list_of_duplicates]), key=str.lower)) if list_size != 0 else "\tNone\n"
+    return (
+        "".join(
+            sorted(
+                set(
+                    [
+                        "\t{0}: '{1}' {2}: '{3}' {4}: '{5}' {6}: '{7}' {8}: '{9}'\n".format(
+                            colored("name", "yellow") if QE_DEVELOPMENT else "name",
+                            repr(node.name),
+                            colored("roleName", "yellow")
+                            if QE_DEVELOPMENT
+                            else "roleName",
+                            node.roleName,
+                            colored("position", "yellow")
+                            if QE_DEVELOPMENT
+                            else "position",
+                            node.position,
+                            colored("size", "yellow") if QE_DEVELOPMENT else "size",
+                            node.size,
+                            colored(f"{attr}", "yellow")
+                            if QE_DEVELOPMENT
+                            else f"{attr}"
+                            if attr
+                            else "attribute",
+                            getattr(node, attr) if attr else "None",
+                        )
+                        for node in list_of_duplicates
+                    ]
+                ),
+                key=str.lower,
+            )
+        )
+        if list_size != 0
+        else "\tNone\n"
+    )
 
 
-def get_formated_error_message(error,
-                               node_name, same_name_items,
-                               node_role_name, same_role_name_items):
+def get_formated_error_message(
+    error, node_name, same_name_items, node_role_name, same_role_name_items
+):
     """
     Take lists of duplicates with name and roleName and format them for error message.
 
@@ -288,13 +348,26 @@ def get_formated_error_message(error,
         Used by :py:func:`get_error_message`.
     """
 
-    return "".join(["\n\n{0}: {1}\n\n{2}: {3}:\n{4}\n{5}: {6}:\n{7}\n".format(
-        colored("Item was not found", "yellow", attrs=["bold"]) \
-            if QE_DEVELOPMENT else "Item was not found", error,
-        colored("Items with name", "yellow", attrs=["bold"]) \
-            if QE_DEVELOPMENT else "Items with name", node_name, same_name_items,
-        colored("Items with roleName", "yellow", attrs=["bold"]) \
-            if QE_DEVELOPMENT else "Items with roleName", node_role_name, same_role_name_items)])
+    return "".join(
+        [
+            "\n\n{0}: {1}\n\n{2}: {3}:\n{4}\n{5}: {6}:\n{7}\n".format(
+                colored("Item was not found", "yellow", attrs=["bold"])
+                if QE_DEVELOPMENT
+                else "Item was not found",
+                error,
+                colored("Items with name", "yellow", attrs=["bold"])
+                if QE_DEVELOPMENT
+                else "Items with name",
+                node_name,
+                same_name_items,
+                colored("Items with roleName", "yellow", attrs=["bold"])
+                if QE_DEVELOPMENT
+                else "Items with roleName",
+                node_role_name,
+                same_role_name_items,
+            )
+        ]
+    )
 
 
 def get_error_message(node, error):
@@ -325,9 +398,9 @@ def get_error_message(node, error):
             lambda x: re.fullmatch(node.name, x.name)
         )
     nodes_with_name_size = len(nodes_with_name)
-    nodes_with_name_formatted = get_formated_duplicates(nodes_with_name_size,
-                                                        nodes_with_name,
-                                                        node.attr)
+    nodes_with_name_formatted = get_formated_duplicates(
+        nodes_with_name_size, nodes_with_name, node.attr
+    )
     role_name = repr(node.role_name)
     nodes_with_role_name = []
     if isinstance(node.role_name, str):
@@ -340,12 +413,14 @@ def get_error_message(node, error):
             lambda x: re.fullmatch(node.role_name, x.roleName)
         )
     nodes_with_role_name_size = len(nodes_with_role_name)
-    nodes_with_role_name_formatted = get_formated_duplicates(nodes_with_role_name_size,
-                                                             nodes_with_role_name,
-                                                             node.attr)
+    nodes_with_role_name_formatted = get_formated_duplicates(
+        nodes_with_role_name_size, nodes_with_role_name, node.attr
+    )
 
-    return get_formated_error_message(error,
-                                      name,
-                                      nodes_with_name_formatted,
-                                      role_name,
-                                      nodes_with_role_name_formatted)
+    return get_formated_error_message(
+        error,
+        name,
+        nodes_with_name_formatted,
+        role_name,
+        nodes_with_role_name_formatted,
+    )
