@@ -1,5 +1,4 @@
 #!/usr/bin/env python3
-import sys
 from os import path
 from time import sleep
 from dogtail.rawinput import click
@@ -10,9 +9,13 @@ from qecore.utility import run
 try:
     import cv2
 except ModuleNotFoundError:
-    print("You need to install an 'opencv-python' via pip or 'python3-opencv' via yum/dnf.")
+    print(
+        "You need to install an 'opencv-python' via pip or 'python3-opencv' via yum/dnf."
+    )
 except ImportError:
-    print("A possibility of an error on secondary architecture. Image matching will not be available.")
+    print(
+        "A possibility of an error on secondary architecture. Image matching will not be available."
+    )
 
 
 HELP_MESSAGE = """
@@ -56,6 +59,7 @@ What is needed for image match:
             position and size are (x, y) tuples of integers
 """
 
+
 @step('Image "{needle}" is shown on screen')
 @step('Image "{needle}" is shown on screen with threshold "{threshold:f}"')
 def image_match(context, needle, threshold=0.8):
@@ -96,9 +100,9 @@ def image_not_match(context, needle, threshold=0.8):
     if positive_match:
         image_match_instance.draw()
         context.attach_opencv = True
-    assert not positive_match, "".join((
-        f"Image '{needle}' was found, that was not supposed to happen."
-    ))
+    assert not positive_match, "".join(
+        (f"Image '{needle}' was found, that was not supposed to happen.")
+    )
 
 
 @step('Image "{needle}" is shown in region')
@@ -117,9 +121,9 @@ def image_region_match(context, needle, threshold=0.8):
     """
 
     region = getattr(context, "opencv_region", None)
-    assert region is not None, "".join((
-        "No region, you must set context.opencv_region first!"
-    ))
+    assert region is not None, "".join(
+        ("No region, you must set context.opencv_region first!")
+    )
     image_match_instance = Matcher(context)
     image_match_instance.capture_image()
     image_match_instance.crop_image(region)
@@ -151,9 +155,10 @@ def image_region_not_match(context, needle, threshold=0.8):
     if positive_match:
         image_match_instance.draw()
         context.attach_opencv = True
-    assert not positive_match, "".join((
-        f"Image '{needle}' was found, that was not supposed to happen."
-    ))
+    assert not positive_match, "".join(
+        (f"Image '{needle}' was found, that was not supposed to happen.")
+    )
+
 
 @step('Locate and click "{needle}"')
 def locate_and_click(context, needle):
@@ -195,7 +200,6 @@ class Matcher:
         self.needle = None
         self.needle_size = None
 
-
     def capture_image(self):
         """
         Captures the image.
@@ -203,7 +207,6 @@ class Matcher:
 
         run(self.capture_image_cmd)
 
-
     def crop_image(self, region):
         """
         Crops the image.
@@ -216,10 +219,9 @@ class Matcher:
         (x, y), (w, h) = region
         if self.context.sandbox.session_type == "wayland":
             y += self.context.sandbox.shell.child("System", "menu").size[1]
-        self.ori_img = self.ori_img[y:y+h, x:x+w]
+        self.ori_img = self.ori_img[y : y + h, x : x + w]
         cv2.imwrite(self.screen_path, self.ori_img)
 
-
     def assert_match(self, needle, threshold=0.8, capture=True):
         """
         Calls and asserts the result of :py:func:`match`.
@@ -234,11 +236,9 @@ class Matcher:
         :param capture: Decides if the image will be captured.
         """
 
-        assert self.match(needle, threshold, capture), "".join((
-            f"Image match value: {self.matched_value}"
-        ))
-
-
+        assert self.match(needle, threshold, capture), "".join(
+            (f"Image match value: {self.matched_value}")
+        )
 
     def match(self, needle, threshold=0.8, capture=True):
         """
@@ -270,18 +270,18 @@ class Matcher:
 
         return self.matched_value > threshold
 
-
     def draw(self):
         """
         Draws the result to the original image.
         """
 
-        self.needle_size = (self.matched_loc[0] + self.needle_width, \
-                            self.matched_loc[1] + self.needle_height)
+        self.needle_size = (
+            self.matched_loc[0] + self.needle_width,
+            self.matched_loc[1] + self.needle_height,
+        )
         cv2.rectangle(self.ori_img, self.matched_loc, self.needle_size, (0, 0, 255), 2)
         cv2.imwrite(self.diff_path, self.ori_img)
 
-
     def click(self):
         """
         Clicks to the center of the result.
