@@ -13,6 +13,7 @@ from qecore.utility import get_application, run
 # As we cannot have online accounts yaml data in, you have to provide them yourself #
 #####################################################################################
 
+
 class Accounts:
     """
     **With this class all accounts are added and removed.**
@@ -34,9 +35,9 @@ class Accounts:
             self.application = get_application(context, "gnome-control-center")
         except Exception:
             # if its not defined in environment.
-            self.application = context.sandbox.get_application(name="gnome-control-center",
-                                                               desktop_file_name="gnome-control-center")
-
+            self.application = context.sandbox.get_application(
+                name="gnome-control-center", desktop_file_name="gnome-control-center"
+            )
 
     def remove_all_accounts(self):
         """
@@ -48,7 +49,9 @@ class Accounts:
 
         target = self.application.instance.child("Connect to your data in the cloud")
         target_panel = target.parent.findChildren(lambda x: x.roleName == "panel")[0]
-        existing_accounts = [x for x in target_panel.findChildren(lambda x: x.roleName == "label")]
+        existing_accounts = [
+            x for x in target_panel.findChildren(lambda x: x.roleName == "label")
+        ]
 
         for account in existing_accounts:
             account.click()
@@ -56,7 +59,6 @@ class Accounts:
 
         self.application.close_via_shortcut()
 
-
     def remove_account(self, account_name):
         """
         Remove single account added via gnome-online-accounts.
@@ -70,7 +72,10 @@ class Accounts:
 
         target = self.application.instance.child("Connect to your data in the cloud")
         target_panel = target.parent.findChildren(lambda x: x.roleName == "panel")[0]
-        existing_accounts = {x.name: x for x in target_panel.findChildren(lambda x: x.roleName == "label")}
+        existing_accounts = {
+            x.name: x
+            for x in target_panel.findChildren(lambda x: x.roleName == "label")
+        }
         try:
             existing_accounts[account_name].click()
             self.application.instance.child("Remove Account").click()
@@ -79,7 +84,6 @@ class Accounts:
 
         self.application.close_via_shortcut()
 
-
     def account_exists(self, account_name):
         """
         Found out if there is an account added via gnome-online-accounts.
@@ -93,15 +97,18 @@ class Accounts:
 
         target = self.application.instance.child("Connect to your data in the cloud")
         target_panel = target.parent.findChildren(lambda x: x.roleName == "panel")[0]
-        existing_accounts = [x.name for x in target_panel.findChildren(lambda x: x.roleName == "label")]
+        existing_accounts = [
+            x.name for x in target_panel.findChildren(lambda x: x.roleName == "label")
+        ]
         result = False
         for account in existing_accounts:
             if account_name in account:
                 result = True
         return result
 
-
-    def add_account(self, account_id, login=None, password=None, server=None, yaml_file=None):
+    def add_account(
+        self, account_id, login=None, password=None, server=None, yaml_file=None
+    ):
         """
         Add account to the gnome-online-accounts.
 
@@ -122,18 +129,28 @@ class Accounts:
         """
 
         self.context.sandbox._detect_keyring()
-        self.account_data = AccountData(account_id, login=login, password=password,
-                                        server=server, yaml_file=yaml_file)
+        self.account_data = AccountData(
+            account_id,
+            login=login,
+            password=password,
+            server=server,
+            yaml_file=yaml_file,
+        )
         account_name = self.account_data.name
 
         self.application.start_via_command("gnome-control-center online-accounts")
 
         target = self.application.instance.child("Connect to your data in the cloud")
         target_panel = target.parent.findChildren(lambda x: x.roleName == "panel")[1]
-        accounts_to_be_added = {x.name: x for x in target_panel.findChildren(lambda x: x.roleName == "label")}
+        accounts_to_be_added = {
+            x.name: x
+            for x in target_panel.findChildren(lambda x: x.roleName == "label")
+        }
         accounts_to_be_added[account_name].click()
 
-        account_login_dialog = self.application.instance.child(f"{account_name} Account", "dialog")
+        account_login_dialog = self.application.instance.child(
+            f"{account_name} Account", "dialog"
+        )
 
         if account_name == "Google":
             add_google_account(self.context, self.account_data, account_login_dialog)
@@ -148,13 +165,19 @@ class Accounts:
         if account_name == "Pocket":
             add_pocket_account(self.context, self.account_data, account_login_dialog)
         if account_name == "Foursquare":
-            add_foursquare_account(self.context, self.account_data, account_login_dialog)
+            add_foursquare_account(
+                self.context, self.account_data, account_login_dialog
+            )
         if account_name == "Microsoft Exchange":
-            add_microsoft_exchange_account(self.context, self.account_data, account_login_dialog)
+            add_microsoft_exchange_account(
+                self.context, self.account_data, account_login_dialog
+            )
 
         sleep(1)
         pressKey("Esc")
-        assert self.account_exists(account_name), f"Account '{account_name}' was not detected.\n"
+        assert self.account_exists(
+            account_name
+        ), f"Account '{account_name}' was not detected.\n"
 
 
 class AccountData:
@@ -162,8 +185,15 @@ class AccountData:
     **With this class we keep and get all data about accounts.**
     """
 
-    def __init__(self, account_id, login=None, password=None,
-                 server=None, yaml_data=None, yaml_file=None):
+    def __init__(
+        self,
+        account_id,
+        login=None,
+        password=None,
+        server=None,
+        yaml_data=None,
+        yaml_file=None,
+    ):
         """
         Account class.
 
@@ -208,7 +238,6 @@ class AccountData:
             self.get_account_data()
             self.parse_account_data()
 
-
     def get_account_data(self, yaml_file="online_accounts.yaml"):
         """
         Load yaml data to the class attribute.
@@ -217,24 +246,26 @@ class AccountData:
         :param yaml_file: Location of the yaml file.
         """
 
-        assert os.path.isfile(yaml_file),\
-            "\n".join((
+        assert os.path.isfile(yaml_file), "\n".join(
+            (
                 "\n\nFor online accounts you need to supply the credentials in yaml format.",
                 "Expecting file 'online_accounts.yaml' in your project directory.",
                 "If not found you have to provide the file yourself and use step-decorator as:.",
-                "'Add \"{account_name}\" account from file \"{yaml_file}\"'\n"
-            ))
+                '\'Add "{account_name}" account from file "{yaml_file}"\'\n',
+            )
+        )
 
         with open(yaml_file, "rb") as data:
             try:
                 self.yaml_data = yaml.safe_load(data)
             except yaml.YAMLError:
                 traceback.print_exc(file=sys.stdout)
-                assert False, " ".join((
-                    "Parsing YAML file was not successful.",
-                    f"Please check format of accounts.yaml file"
-                ))
-
+                assert False, " ".join(
+                    (
+                        "Parsing YAML file was not successful.",
+                        "Please check format of accounts.yaml file",
+                    )
+                )
 
     def parse_account_data(self):
         """
@@ -245,23 +276,31 @@ class AccountData:
         try:
             self.name = self.yaml_data[self.account_id]["name"]
         except KeyError:
-            raise KeyError(f"Name for account '{self.account_id}' is expected, but was not provided.")
+            raise KeyError(
+                f"Name for account '{self.account_id}' is expected, but was not provided."
+            )
 
         try:
             self.login = self.yaml_data[self.account_id]["login"]
         except KeyError:
-            raise KeyError(f"Login for account '{self.account_id}' is expected, but was not provided.")
+            raise KeyError(
+                f"Login for account '{self.account_id}' is expected, but was not provided."
+            )
 
         try:
             self.password = self.yaml_data[self.account_id]["password"]
         except KeyError:
-            raise KeyError(f"Password for account '{self.account_id}' is expected, but was not provided.")
+            raise KeyError(
+                f"Password for account '{self.account_id}' is expected, but was not provided."
+            )
 
         try:
             self.server = self.yaml_data[self.account_id]["server"]
         except KeyError:
             if self.name == "Nextcloud" or self.name == "Microsoft Exchange":
-                raise KeyError(f"Server for account '{self.account_id}' is expected, but was not provided.")
+                raise KeyError(
+                    f"Server for account '{self.account_id}' is expected, but was not provided."
+                )
 
 
 def wait_until_progress_bar_dissapears_in(account_login_dialog):
@@ -272,7 +311,9 @@ def wait_until_progress_bar_dissapears_in(account_login_dialog):
     :param account_login_dialog: Node in which the progress bar is being searched in.
     """
 
-    progress_bar = account_login_dialog.findChildren(lambda x: x.roleName == "progress bar")
+    progress_bar = account_login_dialog.findChildren(
+        lambda x: x.roleName == "progress bar"
+    )
     while progress_bar and progress_bar[0].showing:
         sleep(0.2)
 
@@ -348,10 +389,14 @@ def add_nextcloud_account(context, data, account_login_dialog):
     server_entry = account_login_dialog.findChildren(lambda x: x.roleName == "text")[1]
     server_entry.text = data.server
 
-    username_entry = account_login_dialog.findChildren(lambda x: x.roleName == "text")[0]
+    username_entry = account_login_dialog.findChildren(lambda x: x.roleName == "text")[
+        0
+    ]
     username_entry.text = data.login
 
-    password_entry = account_login_dialog.findChildren(lambda x: x.roleName == "password text")[0]
+    password_entry = account_login_dialog.findChildren(
+        lambda x: x.roleName == "password text"
+    )[0]
     password_entry.text = data.password
 
     account_login_dialog.child("Connect").click()
@@ -509,8 +554,10 @@ def add_pocket_account(context, data, account_login_dialog):
     wait_until_progress_bar_dissapears_in(account_login_dialog)
     try:
         assert account_login_dialog.findChild(
-            lambda x: x.roleName == "paragraph" and x.text == "desktopqe.pocket@gmail.com",
-        retry=False)
+            lambda x: x.roleName == "paragraph"
+            and x.text == "desktopqe.pocket@gmail.com",
+            retry=False,
+        )
         pressKey("PageDown")
     except Exception:
         email_entry = account_login_dialog.child("Email", "entry")
@@ -605,7 +652,9 @@ def add_microsoft_exchange_account(context, data, account_login_dialog):
     email_entry.click()
     email_entry.text = data.login
 
-    password_entry = account_login_dialog.findChildren(lambda x: x.roleName == "password text")[0]
+    password_entry = account_login_dialog.findChildren(
+        lambda x: x.roleName == "password text"
+    )[0]
     password_entry.click()
     password_entry.text = data.password
 
@@ -640,15 +689,19 @@ def add_account(context, account_name, login=None, password=None, yaml_file=None
 
     accounts = Accounts(context)
     try:
-        accounts.add_account(account_name, login=login, password=password, yaml_file=yaml_file)
+        accounts.add_account(
+            account_name, login=login, password=password, yaml_file=yaml_file
+        )
     except KeyError as error:
         raise KeyError(error)
     except Exception:
         run(f"rm -rf {os.path.expanduser('~')}/.local/share/webkitgtk/*")
-        accounts.add_account(account_name, login=login, password=password, yaml_file=yaml_file)
+        accounts.add_account(
+            account_name, login=login, password=password, yaml_file=yaml_file
+        )
 
 
-@step('Remove all accounts')
+@step("Remove all accounts")
 def remove_accounts(context):
     """
     Function with behave step decorator::
