@@ -18,6 +18,7 @@ USAGE::
     use_step_matcher("parse") # stop using qecore matcher
 """
 
+
 def use_step_matcher(matcher_name):
     """
     Overrides `behave.matchers.use_step_matcher()` function.
@@ -29,6 +30,7 @@ def use_step_matcher(matcher_name):
 
     from behave.matchers import matcher_mapping
     from behave.matchers import use_step_matcher as usm
+
     matcher_mapping["qecore"] = QecoreMatcher
     usm(matcher_name)
 
@@ -69,12 +71,13 @@ class QecoreMatcher(ParseMatcher):
         """
         super(QecoreMatcher, self).__init__(func, pattern, step_type)
         # Note the space at the end of patterns (to make sure whole words are matched).
-        self.patterns = [f"{self.start_phrase}{p.strip()} " for p in pattern.split(self.delimiter)]
+        self.patterns = [
+            f"{self.start_phrase}{p.strip()} " for p in pattern.split(self.delimiter)
+        ]
         self.parsers = {}
         for patt in self.patterns:
             self.parsers[patt] = self.parser_class(patt, self.custom_types)
 
-
     def check_match(self, step):
         """
         Check if step matches definition and also for duplicit step definitions.
@@ -90,8 +93,7 @@ class QecoreMatcher(ParseMatcher):
         # Escaped quotes and append space (because patterns end with space).
         step_suffix = self.start_phrase + step.replace('\\"', "''") + " "
         # To calculate positions in step argument - used for keword highlights.
-        offset = - len(self.start_phrase)
-
+        offset = -len(self.start_phrase)
 
         def fix_escape_quotes(value, text_repr):
             """
@@ -112,7 +114,6 @@ class QecoreMatcher(ParseMatcher):
             text_repr = text_repr.replace("''", '"')
             return value, text_repr
 
-
         def process_result(step_suffix, offset, args, result, pattern):
             """
             Convert parse results into behave arguments.
@@ -138,16 +139,20 @@ class QecoreMatcher(ParseMatcher):
             for index, value in enumerate(result.fixed):
                 start, end = result.spans[index]
                 value, text_repr = fix_escape_quotes(value, step_suffix[start:end])
-                args.append(Argument(start+offset, end+offset, text_repr, value))
+                args.append(Argument(start + offset, end + offset, text_repr, value))
             for name, value in result.named.items():
                 start, end = result.spans[name]
                 value, text_repr = fix_escape_quotes(value, step_suffix[start:end])
-                args.append(Argument(start+offset, end+offset, text_repr, value, name))
+                args.append(
+                    Argument(start + offset, end + offset, text_repr, value, name)
+                )
             # Matched part of the step.
             pattern_filled = pattern.format_map(result.named)
             # Remove matched part and append start_phrase.
             old_len = len(step_suffix)
-            step_suffix = self.start_phrase + step_suffix.replace(pattern_filled, "").lstrip(" |")
+            step_suffix = self.start_phrase + step_suffix.replace(
+                pattern_filled, ""
+            ).lstrip(" |")
             new_len = len(step_suffix)
             # Calculate offset.
             offset += old_len - new_len
@@ -162,7 +167,9 @@ class QecoreMatcher(ParseMatcher):
 
         if result is None:
             return None
-        step_suffix, offset, args = process_result(step_suffix, offset, args, result, pattern)
+        step_suffix, offset, args = process_result(
+            step_suffix, offset, args, result, pattern
+        )
 
         # Match rest of the step.
         patterns = self.patterns[1:]
@@ -174,8 +181,9 @@ class QecoreMatcher(ParseMatcher):
                     continue
                 # Remove pattern as it was used.
                 patterns.remove(pattern)
-                step_suffix, offset, args = process_result(step_suffix, offset,
-                                                           args, result, pattern)
+                step_suffix, offset, args = process_result(
+                    step_suffix, offset, args, result, pattern
+                )
                 found = True
             if not found:
                 return None
